The :class:`ConcurrentSimIndex` Class
-------------------------------------

.. automodule:: pysimsearch.sim_index.concurrent_sim_index

.. autoclass:: pysimsearch.sim_index.ConcurrentSimIndex
   :members:
   :inherited-members:
